==> tuia-advert-center-api-2.5.55-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertMaterialTestPlanDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;

public class AdvertMaterialTestPlanDataDto implements Serializable {

    private static final long serialVersionUID = 1119442328478635251L;

    //广告id
    private Long advertId;
    //测试计划id
    private Long testPlanId;
    //配置id
    private Long orientId;
    //素材id
    private Long materialId;

    //广告id
    private Integer advertType;
    //素材名称
    private String materialName;
    //素材图片url
    private String materialUrl;
    //是否默认素材
    private Integer isDefault;
    //素材是否激活
    private Integer isActive;
    // 弹层ID
    private Long windId;

    //测试计划开始时间
    private String startTime;
    //测试计划结束时间
    private String endTime;
    //消费
    private String comsumeTotal;
    //以下详见数据库
    private String exposureCount;
    private Long launchCount;
    private String clickRate;
    private Long efClickCount;
    private Long visitPv;
    private String visitRate;
    private Long effectPv;
    private Long startPv;
    private Long registePv;
    private Long activatePv;
    private Long installPv;
    private Long payPv;
    private Long entryPv;
    private Long finishPv;
    private Long loginPv;
    private Long signPv;
    private Long denyPv;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getTestPlanId() {
        return testPlanId;
    }

    public void setTestPlanId(Long testPlanId) {
        this.testPlanId = testPlanId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialUrl() {
        return materialUrl;
    }

    public void setMaterialUrl(String materialUrl) {
        this.materialUrl = materialUrl;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    public Integer getIsActive() {
        return isActive;
    }

    public void setIsActive(Integer isActive) {
        this.isActive = isActive;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getComsumeTotal() {
        return comsumeTotal;
    }

    public void setComsumeTotal(String comsumeTotal) {
        this.comsumeTotal = comsumeTotal;
    }

    public String getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(String exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public String getClickRate() {
        return clickRate;
    }

    public void setClickRate(String clickRate) {
        this.clickRate = clickRate;
    }

    public Long getEfClickCount() {
        return efClickCount;
    }

    public void setEfClickCount(Long efClickCount) {
        this.efClickCount = efClickCount;
    }

    public Long getVisitPv() {
        return visitPv;
    }

    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    public String getVisitRate() {
        return visitRate;
    }

    public void setVisitRate(String visitRate) {
        this.visitRate = visitRate;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getEntryPv() {
        return entryPv;
    }

    public void setEntryPv(Long entryPv) {
        this.entryPv = entryPv;
    }

    public Long getFinishPv() {
        return finishPv;
    }

    public void setFinishPv(Long finishPv) {
        this.finishPv = finishPv;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getSignPv() {
        return signPv;
    }

    public void setSignPv(Long signPv) {
        this.signPv = signPv;
    }

    public Long getDenyPv() {
        return denyPv;
    }

    public void setDenyPv(Long denyPv) {
        this.denyPv = denyPv;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public Long getWindId() {
        return windId;
    }

    public void setWindId(Long windId) {
        this.windId = windId;
    }
}

==> tuia-advert-center-api-2.5.96-sources.jar: cn/com/duiba/tuia/core/api/dto/AdvertMaterialTestPlanDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;
import java.math.BigDecimal;

public class AdvertMaterialTestPlanDataDto implements Serializable {

    private static final long serialVersionUID = 1119442328478635251L;

    //广告id
    private Long advertId;
    //测试计划id
    private Long testPlanId;
    //配置id
    private Long orientId;
    //素材id
    private Long materialId;

    //广告id
    private Integer advertType;
    //素材名称
    private String materialName;
    //素材图片url
    private String materialUrl;
    //是否默认素材
    private Integer isDefault;
    //素材是否激活
    private Integer isActive;
    // 弹层ID
    private Long windId;

    //测试计划开始时间
    private String startTime;
    //测试计划结束时间
    private String endTime;
    //消费
    private String comsumeTotal;
    //以下详见数据库
    private String exposureCount;
    private Long launchCount;
    private String clickRate;
    private Long efClickCount;
    private Long visitPv;
    private String visitRate;
    private Long effectPv;
    private Long startPv;
    private Long registePv;
    private Long activatePv;
    private Long installPv;
    private Long payPv;
    private Long entryPv;
    private Long finishPv;
    private Long loginPv;
    private Long signPv;
    private Long denyPv;
    /**
     * 付款金额
     */
    private BigDecimal paymentAmount;

    public BigDecimal getPaymentAmount() {
        return paymentAmount;
    }

    public void setPaymentAmount(BigDecimal paymentAmount) {
        this.paymentAmount = paymentAmount;
    }
    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getTestPlanId() {
        return testPlanId;
    }

    public void setTestPlanId(Long testPlanId) {
        this.testPlanId = testPlanId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialUrl() {
        return materialUrl;
    }

    public void setMaterialUrl(String materialUrl) {
        this.materialUrl = materialUrl;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    public Integer getIsActive() {
        return isActive;
    }

    public void setIsActive(Integer isActive) {
        this.isActive = isActive;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getComsumeTotal() {
        return comsumeTotal;
    }

    public void setComsumeTotal(String comsumeTotal) {
        this.comsumeTotal = comsumeTotal;
    }

    public String getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(String exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public String getClickRate() {
        return clickRate;
    }

    public void setClickRate(String clickRate) {
        this.clickRate = clickRate;
    }

    public Long getEfClickCount() {
        return efClickCount;
    }

    public void setEfClickCount(Long efClickCount) {
        this.efClickCount = efClickCount;
    }

    public Long getVisitPv() {
        return visitPv;
    }

    public void setVisitPv(Long visitPv) {
        this.visitPv = visitPv;
    }

    public String getVisitRate() {
        return visitRate;
    }

    public void setVisitRate(String visitRate) {
        this.visitRate = visitRate;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getEntryPv() {
        return entryPv;
    }

    public void setEntryPv(Long entryPv) {
        this.entryPv = entryPv;
    }

    public Long getFinishPv() {
        return finishPv;
    }

    public void setFinishPv(Long finishPv) {
        this.finishPv = finishPv;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getSignPv() {
        return signPv;
    }

    public void setSignPv(Long signPv) {
        this.signPv = signPv;
    }

    public Long getDenyPv() {
        return denyPv;
    }

    public void setDenyPv(Long denyPv) {
        this.denyPv = denyPv;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public Long getWindId() {
        return windId;
    }

    public void setWindId(Long windId) {
        this.windId = windId;
    }
}
